@@ -23,6 +23,9 @@ describe 'aodh::keystone::auth' do
         :password            => 'aodh_password',
         :email               => 'aodh@localhost',
         :tenant              => 'services',
+        :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:8042',
         :internal_url        => 'http://127.0.0.1:8042',
         :admin_url           => 'http://127.0.0.1:8042',
@@ -35,6 +38,9 @@ describe 'aodh::keystone::auth' do
           :auth_name           => 'alt_aodh',
           :email               => 'alt_aodh@alt_localhost',
           :tenant              => 'alt_service',
+          :roles               => ['admin', 'service'],
+          :system_scope        => 'alt_all',
+          :system_roles        => ['admin', 'member', 'reader'],
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
@@ -59,6 +65,9 @@ describe 'aodh::keystone::auth' do
         :password            => 'aodh_password',
         :email               => 'alt_aodh@alt_localhost',
         :tenant              => 'alt_service',
+        :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
         :internal_url        => 'http://10.10.10.11:81',
         :admin_url           => 'http://10.10.10.12:81',
