@@ -8,12 +8,37 @@ describe 'aodh::notifier' do
 
   shared_examples_for 'aodh-notifier' do
 
+    context 'with workers' do
+      let :params do
+        { :workers => 8 }
+      end
+
+      it 'configures workers' do
+        is_expected.to contain_aodh_config('notifier/workers').with_value(8)
+      end
+    end
+
+    context 'with batch parameters' do
+      let :params do
+        {
+          :batch_size    => 100,
+          :batch_timeout => 60,
+        }
+      end
+
+      it 'configures batch options' do
+        is_expected.to contain_aodh_config('notifier/batch_size').with_value(100)
+        is_expected.to contain_aodh_config('notifier/batch_timeout').with_value(60)
+      end
+    end
+
     context 'when enabled' do
       it { is_expected.to contain_class('aodh::params') }
 
       it 'installs aodh-notifier package' do
-        is_expected.to contain_package(platform_params[:notifier_package_name]).with(
+        is_expected.to contain_package('aodh-notifier').with(
           :ensure => 'present',
+          :name   => platform_params[:notifier_package_name],
           :tag    => ['openstack', 'aodh-package']
         )
       end
@@ -29,6 +54,11 @@ describe 'aodh::notifier' do
         )
       end
 
+      it 'sets default values' do
+        is_expected.to contain_aodh_config('notifier/workers').with_value(4)
+        is_expected.to contain_aodh_config('notifier/batch_size').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('notifier/batch_timeout').with_value('<SERVICE DEFAULT>')
+      end
     end
 
     context 'when disabled' do
@@ -67,7 +97,7 @@ describe 'aodh::notifier' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts())
+        facts.merge!(OSDefaults.get_facts({ :os_workers => 4 }))
       end
 
       let(:platform_params) do
